package utils;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.sun.org.slf4j.internal.Logger;
import com.sun.org.slf4j.internal.LoggerFactory;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * @Author: zyl
 * @CreateTime: 2024-12-10
 * @Description:
 * @Version: 1.0
 */
public class SignUtils {

    public static Logger logger = LoggerFactory.getLogger(SignUtils.class);
    // 签名验签服务URL
    private static final String URL = "http://172.27.168.231:8088";
    // 签名验签厂商提供的认证code
    private static final String AUTH_CODE = "gFMIkg4IUo";

    // 获取签名
    public static JSONObject getSign(String jsonString, String createBy) throws IOException {
        String url = URL + "/svs-server/svsServer/bizSign/sign";
        System.out.println("url: " + url);
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("inData", jsonString);
        map.put("authCode", AUTH_CODE);
        map.put("reqType", 2);
        map.put("createBy", createBy);
        map.put("crl", false);
        map.put("certificateChain", false);
        map.put("originalText", false);
        map.put("reqTime", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, DateUtils.getNowDate()));

        System.out.println(JSON.toJSONString(map));

        String result = HttpRequest.sendPostDataByJson(url, JSON.toJSONString(map), null);
        logger.error("wandaResult: " + result);
        if (!JSONObject.isValid(result)) {
            return null;
        }
        JSONObject jsonObject = JSONObject.parseObject(FinalUtils.handleJsonString(result));
        JSONObject responseJson = jsonObject.getJSONObject("response");
        logger.error("wandaResult responseJson: " + jsonObject);
        if (StringUtils.isEmpty(responseJson.getString("respValue")) || !responseJson.getString("respValue").equals("0")) {
            return null;
        }
        return jsonObject;
    }

    //验签 创建人为空
    public static JSONObject verifySign(String respType, String sign, String jsonString) throws IOException {
        String url = URL + "/svs-server/svsServer/bizSign/verifySign";
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("authCode", AUTH_CODE);
        if ("3".equals(respType)) { // P7 不带原文时必传,P7 带原文可以不传
            map.put("inData", jsonString);
        }
        map.put("reqType", 2);
        map.put("signature", sign);
        map.put("cert", "");
        map.put("verifyLevel", 0);
        map.put("createBy", "");
        map.put("reqTime", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, DateUtils.getNowDate()));

        System.out.println(JSON.toJSONString(map));

        String result = HttpRequest.sendPostDataByJson(url, JSON.toJSONString(map), null);
        logger.error("wandaResult: " + result);
        if (!JSONObject.isValid(result)) {
            return null;
        }
        JSONObject jsonObject = JSONObject.parseObject(FinalUtils.handleJsonString(result));
        JSONObject responseJson = jsonObject.getJSONObject("response");
        if (StringUtils.isEmpty(responseJson.getString("respValue")) || !responseJson.getString("respValue").equals("0")) {
            return null;
        }
        return jsonObject;
    }

    //验签 包含创建人不为空
    public static JSONObject verifySign(String respType, String sign, String jsonString, String createBy) throws IOException {
        String url = URL + "/svs-server/svsServer/bizSign/verifySign";
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("authCode", AUTH_CODE);
        if ("3".equals(respType)) { // P7 不带原文时必传,P7 带原文可以不传
            map.put("inData", jsonString);
        }
        map.put("reqType", 2);
        map.put("signature", sign);
        map.put("cert", "");
        map.put("verifyLevel", 0);
        map.put("createBy", createBy);
        map.put("reqTime", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, DateUtils.getNowDate()));

        System.out.println(JSON.toJSONString(map));

        String result = HttpRequest.sendPostDataByJson(url, JSON.toJSONString(map), null);
        logger.error("wandaResult: " + result);
        if (!JSONObject.isValid(result)) {
            return null;
        }
        JSONObject jsonObject = JSONObject.parseObject(FinalUtils.handleJsonString(result));
        JSONObject responseJson = jsonObject.getJSONObject("response");
        if (StringUtils.isEmpty(responseJson.getString("respValue")) || !responseJson.getString("respValue").equals("0")) {
            return null;
        }
        return jsonObject;
    }
}